==> kubernetes-model-resource-6.6.1-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimFluent<A extends ResourceClaimFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ResourceClaimFluent.MetadataNested<A> withNewMetadata();
  public ResourceClaimFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ResourceClaimFluent.MetadataNested<A> editMetadata();
  public ResourceClaimFluent.MetadataNested<A> editOrNewMetadata();
  public ResourceClaimFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimSpec getSpec();
  public ResourceClaimSpec buildSpec();
  public A withSpec(ResourceClaimSpec spec);
  public Boolean hasSpec();
  public ResourceClaimFluent.SpecNested<A> withNewSpec();
  public ResourceClaimFluent.SpecNested<A> withNewSpecLike(ResourceClaimSpec item);
  public ResourceClaimFluent.SpecNested<A> editSpec();
  public ResourceClaimFluent.SpecNested<A> editOrNewSpec();
  public ResourceClaimFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimStatus getStatus();
  public ResourceClaimStatus buildStatus();
  public A withStatus(ResourceClaimStatus status);
  public Boolean hasStatus();
  public ResourceClaimFluent.StatusNested<A> withNewStatus();
  public ResourceClaimFluent.StatusNested<A> withNewStatusLike(ResourceClaimStatus item);
  public ResourceClaimFluent.StatusNested<A> editStatus();
  public ResourceClaimFluent.StatusNested<A> editOrNewStatus();
  public ResourceClaimFluent.StatusNested<A> editOrNewStatusLike(ResourceClaimStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ResourceClaimFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ResourceClaimSpecFluent<ResourceClaimFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,ResourceClaimStatusFluent<ResourceClaimFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimFluent<A extends ResourceClaimFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public ResourceClaimFluent.MetadataNested<A> withNewMetadata();
  public ResourceClaimFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public ResourceClaimFluent.MetadataNested<A> editMetadata();
  public ResourceClaimFluent.MetadataNested<A> editOrNewMetadata();
  public ResourceClaimFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimSpec getSpec();
  public ResourceClaimSpec buildSpec();
  public A withSpec(ResourceClaimSpec spec);
  public Boolean hasSpec();
  public ResourceClaimFluent.SpecNested<A> withNewSpec();
  public ResourceClaimFluent.SpecNested<A> withNewSpecLike(ResourceClaimSpec item);
  public ResourceClaimFluent.SpecNested<A> editSpec();
  public ResourceClaimFluent.SpecNested<A> editOrNewSpec();
  public ResourceClaimFluent.SpecNested<A> editOrNewSpecLike(ResourceClaimSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ResourceClaimStatus getStatus();
  public ResourceClaimStatus buildStatus();
  public A withStatus(ResourceClaimStatus status);
  public Boolean hasStatus();
  public ResourceClaimFluent.StatusNested<A> withNewStatus();
  public ResourceClaimFluent.StatusNested<A> withNewStatusLike(ResourceClaimStatus item);
  public ResourceClaimFluent.StatusNested<A> editStatus();
  public ResourceClaimFluent.StatusNested<A> editOrNewStatus();
  public ResourceClaimFluent.StatusNested<A> editOrNewStatusLike(ResourceClaimStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<ResourceClaimFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,ResourceClaimSpecFluent<ResourceClaimFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,ResourceClaimStatusFluent<ResourceClaimFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
